@@ -9,7 +9,7 @@ import (
 	"strings"
 
 	"github.com/gobwas/glob"
-	hcl "github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hcldec"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
@@ -109,10 +109,6 @@ func (cfg *PackerConfig) EvalContext(ctx BlockContext, variables map[string]cty.
 				"name": cty.UnknownVal(cty.String),
 			}),
 			buildAccessor: cty.UnknownVal(cty.EmptyObject),
-			packerAccessor: cty.ObjectVal(map[string]cty.Value{
-				"version":     cty.StringVal(cfg.CorePackerVersionString),
-				"iterationID": cty.UnknownVal(cty.String),
-			}),
 			pathVariablesAccessor: cty.ObjectVal(map[string]cty.Value{
 				"cwd":  cty.StringVal(strings.ReplaceAll(cfg.Cwd, `\`, `/`)),
 				"root": cty.StringVal(strings.ReplaceAll(cfg.Basedir, `\`, `/`)),
@@ -120,13 +116,22 @@ func (cfg *PackerConfig) EvalContext(ctx BlockContext, variables map[string]cty.
 		},
 	}
 
+	packerVars := map[string]cty.Value{
+		"version":            cty.StringVal(cfg.CorePackerVersionString),
+		"iterationID":        cty.UnknownVal(cty.String),
+		"versionFingerprint": cty.UnknownVal(cty.String),
+	}
+
 	iterID, ok := cfg.HCPVars["iterationID"]
 	if ok {
-		ectx.Variables[packerAccessor] = cty.ObjectVal(map[string]cty.Value{
-			"version":     cty.StringVal(cfg.CorePackerVersionString),
-			"iterationID": iterID,
-		})
+		packerVars["iterationID"] = iterID
 	}
+	versionFP, ok := cfg.HCPVars["versionFingerprint"]
+	if ok {
+		packerVars["versionFingerprint"] = versionFP
+	}
+
+	ectx.Variables[packerAccessor] = cty.ObjectVal(packerVars)
 
 	// In the future we'd like to load and execute HCL blocks using a graph
 	// dependency tree, so that any block can use any block whatever the
