@@ -595,6 +595,10 @@ func (bucket *Bucket) startBuild(ctx context.Context, buildName string) error {
 	return nil
 }
 
+type NotAHCPArtifactError struct {
+	error
+}
+
 func (bucket *Bucket) completeBuild(
 	ctx context.Context,
 	buildName string,
@@ -638,20 +642,35 @@ func (bucket *Bucket) completeBuild(
 		}
 
 		state := art.State(packerSDKRegistry.ArtifactStateURI)
+		if state == nil {
+			log.Printf("[WARN] - artifact %q returned a nil value for the HCP state, ignoring", art.BuilderId())
+			continue
+		}
+
 		err = decoder.Decode(state)
 		if err != nil {
-			return packerSDKArtifacts, fmt.Errorf(
-				"failed to obtain HCP Packer compliant artifact: %w",
-				err)
+			log.Printf("[WARN] - artifact %q failed to be decoded to an HCP artifact, this is probably because it is not compatible: %s", art.BuilderId(), err)
+			continue
 		}
-		log.Printf("[TRACE] updating artifacts for build %q", buildName)
-		err = bucket.UpdateArtifactForBuild(buildName, sdkImages...)
 
+		err = bucket.UpdateArtifactForBuild(buildName, sdkImages...)
 		if err != nil {
 			return packerSDKArtifacts, fmt.Errorf("failed to add artifact for %q: %s", buildName, err)
 		}
 	}
 
+	build, err := bucket.Version.Build(buildName)
+	if err != nil {
+		return packerSDKArtifacts, fmt.Errorf(
+			"failed to get build %q from version being built. This is a Packer bug.",
+			buildName)
+	}
+	if len(build.Artifacts) == 0 {
+		return packerSDKArtifacts, &NotAHCPArtifactError{
+			fmt.Errorf("No HCP Packer-compatible artifacts were found for the build"),
+		}
+	}
+
 	parErr := bucket.markBuildComplete(ctx, buildName)
 	if parErr != nil {
 		return packerSDKArtifacts, fmt.Errorf(
